#
# spec file for package python-python-prctl
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-python-prctl
Version:        1.7
Release:        2.15
Summary:        Python(ic) interface to the linux prctl syscall
License:        GPL-3.0-or-later
URL:            https://github.com/seveas/python-prctl
Source:         https://files.pythonhosted.org/packages/source/p/python-prctl/python-prctl-%{version}.tar.gz
Source99:       https://raw.githubusercontent.com/seveas/python-prctl/master/COPYING
Patch0:         disable-sandboxed-test.patch
Patch1:         memory_failure_early_kill.patch
Patch2:         bigendian.patch
Patch3:         powerpc.patch
Patch4:         disable_no_new_privs.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  iputils
BuildRequires:  pkgconfig
BuildRequires:  procps
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libcap)
%python_subpackages

%description
The linux prctl function allows you to control specific characteristics of a
process' behaviour. Usage of the function is fairly messy though, due to
limitations in C and linux. This module provides a nice non-messy python(ic)
interface.

Besides prctl, this library also wraps libcap for complete capability handling
and allows you to set the process name as seen in ps and top.

%prep
%setup -q -n python-prctl-%{version}
%autopatch -p1
cp %{SOURCE99} .

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python -m unittest discover -v

%files %{python_files}
%license COPYING
%doc README
%{python_sitearch}/*

%changelog
* Tue Oct 27 2020 hpj@urpla.net
- Disable test of no_new_privs with disable_no_new_privs.patch
  test fails, because ping doesn't use capabilities anymore (boo#1174504)
* Fri Sep  4 2020 mcalabkova@suse.com
- Fixing arch-dependent test failures (bsc#1176085):
  * renamed failing-on-i586.patch to memory_failure_early_kill.patch
  * and modified it to skip the test also on s390x
  * added bigendian.patch
  * added powerpc.patch
  * huge thanks to Michal Suchánek
* Wed Aug 19 2020 mcalabkova@suse.com
- Add failing-on-i586.patch to disable failing i586 test
* Tue Aug 11 2020 tchvatal@suse.com
- Add patch to disable test failing in sandbox:
  https://github.com/seveas/python-prctl/issues/17
  * disable-sandboxed-test.patch
* Tue Aug 11 2020 tchvatal@suse.com
- Initial commit jsc#SLE-13272
